@@ -36,10 +36,26 @@ class CheckStream(ConnectionChecker, JsonSchemaMixin):
             if stream_name in stream_name_to_stream.keys():
                 stream = stream_name_to_stream[stream_name]
                 try:
-                    records = stream.read_records(sync_mode=SyncMode.full_refresh)
+                    # Some streams need a stream slice to read records (eg if they have a SubstreamSlicer)
+                    stream_slice = self._get_stream_slice(stream)
+                    records = stream.read_records(sync_mode=SyncMode.full_refresh, stream_slice=stream_slice)
                     next(records)
                 except Exception as error:
                     return False, f"Unable to connect to stream {stream_name} - {error}"
             else:
                 raise ValueError(f"{stream_name} is not part of the catalog. Expected one of {stream_name_to_stream.keys()}")
         return True, None
+
+    def _get_stream_slice(self, stream):
+        # We wrap the return output of stream_slices() because some implementations return types that are iterable,
+        # but not iterators such as lists or tuples
+        slices = iter(
+            stream.stream_slices(
+                cursor_field=stream.cursor_field,
+                sync_mode=SyncMode.full_refresh,
+            )
+        )
+        try:
+            return next(slices)
+        except StopIteration:
+            return {}
