@@ -34,3 +34,6 @@ class PageIncrement(PaginationStrategy, JsonSchemaMixin):
 
     def reset(self):
         self._page = 0
+
+    def get_page_size(self) -> Optional[int]:
+        return self.page_size
