@@ -1,13 +1,14 @@
 #
-# Copyright (c) 2021 Airbyte, Inc., all rights reserved.
+# Copyright (c) 2022 Airbyte, Inc., all rights reserved.
 #
 
 # Initialize Auth Package
 from .core import HttpAuthenticator, NoAuth
 from .oauth import Oauth2Authenticator
-from .token import MultipleTokenAuthenticator, TokenAuthenticator
+from .token import BasicHttpAuthenticator, MultipleTokenAuthenticator, TokenAuthenticator
 
 __all__ = [
+    "BasicHttpAuthenticator",
     "HttpAuthenticator",
     "NoAuth",
     "Oauth2Authenticator",
